@@ -48,7 +48,7 @@ class EventsManager extends CGExtensions
 			$name = $this->Lang('friendlyname');
 		return $name;
 	}
-	function GetVersion() { return '1.2.6'; }
+	function GetVersion() { return '1.2.7'; }
 	function GetHelp() {
 		$main_help = $this->Lang('help');
 		$examples_help = $this->Lang('help_examples');
@@ -135,6 +135,7 @@ class EventsManager extends CGExtensions
 		$this->SetParameterType('allow_notconnected', CLEAN_INT);
 		$this->SetParameterType('redirectdetail', CLEAN_INT);
 		$this->SetParameterType('overquotanb', CLEAN_INT);
+		$this->SetParameterType('overquotatotal', CLEAN_INT);
 		
 		// Templates
 		$this->SetParameterType('summarytemplate', CLEAN_STRING);
@@ -160,6 +161,7 @@ class EventsManager extends CGExtensions
 		$this->CreateParameter('allow_notconnected', '0', $this->Lang('param_allow_notconnected'));
 		$this->CreateParameter('redirectdetail', '0', $this->Lang('param_redirectdetail'));
 		$this->CreateParameter('overquotanb');
+		$this->CreateParameter('overquotatotal');
 		
 		// Templates
 		$this->CreateParameter('summarytemplate', '', $this->Lang('param_summarytemplate'));
