@@ -7,6 +7,9 @@ $errors = array();
 $messages = array();
 $this->SetCurrentTab('events');
 
+/* Customfields managed by AireLibs */
+$FieldsManager = new AireFieldsManager();
+
 // Add or edit ?
 if (isset($params['id_event']))
 {
@@ -22,7 +25,7 @@ else
 $event = new EventsManager_event($id_event);
 
 // The event is loaded, but if it's a copy, we have to tell the system that it's not a modification but a creation
-if ($params['copy'])
+if (isset($params['copy']))
 {
 	$mode = 'copy';
 	$event->id = false;
@@ -32,13 +35,21 @@ if ($params['copy'])
 if (isset($params['submit']))
 {
 	// Get the params
-	$event->name = trim($params['name']);
-	$event->description = trim($params['description']);
-	$event->id_category = $params['id_category'];
+	$event->load_from_array($params);
+	// Specific operations
+	//$event->name = trim($params['name']);
+	//$event->description = trim($params['description']);
 	$event->start_datetime = trim($params['start_date']) . ' ' . trim($params['start_time'] . ':00');
 	$event->end_datetime = trim($params['end_date']) . ' ' . trim($params['end_time'] . ':00');
-	$event->url = trim($params['url']);
-	$event->price = trim($params['price']);
+	$event->reg_start_datetime = trim($params['reg_start_date']) . ' ' . trim($params['reg_start_time'] . ':00');
+	$event->reg_end_datetime = trim($params['reg_end_date']) . ' ' . trim($params['reg_end_time'] . ':00');
+
+	if (isset($params['url']))
+		$event->url = trim($params['url']);
+	//$event->price = trim($params['price']);
+
+	if (!isset($params['cancelled']))
+		$event->cancelled=0;
 	
 	// Manage the capacity
 	if (isset($params['capacity_unlimited']) OR trim($params['capacity_input']) == '')
@@ -51,6 +62,11 @@ if (isset($params['submit']))
 		$event->allow_registration = 1;
 	else
 		$event->allow_registration = 0;
+	// Use reg period ?
+	if (isset($params['limited_reg_period']))
+		$event->limited_reg_period = 1;
+	else
+		$event->limited_reg_period = 0;
 		
 	// FEU Groups allowed to register
 	if (isset($params['allowed_feu_groups']))
@@ -86,6 +102,9 @@ if (isset($params['submit']))
 				$this->SendEvent('EventsManagerEventEdited', $parms);
 			else
 				$this->SendEvent('EventsManagerEventAdded', $parms);
+
+			// CustomFields management
+			$FieldsManager->store_fields_from_params($id, $params, $event->id);
 			
 			$this->RedirectToTab($id);
 		}
@@ -100,7 +119,7 @@ elseif (isset($params['cancel']))
 // Assign to smarty */
 
 /* Form general vars */
-$smarty->assign('form_start', $this->CreateFormStart($id, 'admin_addeditevent', $returnid));
+$smarty->assign('form_start', $this->CreateFormStart($id, 'admin_addeditevent', $returnid, 'POST', 'multipart/form-data'));
 $smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
 $smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
 $smarty->assign('form_end', $this->CreateFormEnd());
@@ -126,6 +145,15 @@ $smarty->assign('url_input', $this->CreateInputText($id, 'url', $event->url, 60,
 $smarty->assign('price_label', $this->CreateLabelForInput($id, 'price', $this->Lang('price')));
 $smarty->assign('price_input', $this->CreateInputText($id, 'price', $event->price, 20, 30));
 
+// Status
+$status_drop = array($this->Lang('published')=>'published', $this->Lang('draft')=>'draft');
+$smarty->assign('status_label', $this->Lang('status'));
+$smarty->assign('status_input', $this->CreateInputDropdown($id, 'status', $status_drop, '', $event->status));
+
+// Cancelled ?
+$smarty->assign('cancelled_label', $this->CreateLabelForInput($id, 'cancelled', $this->Lang('event_cancelled')));
+$smarty->assign('cancelled_input', $this->CreateInputCheckbox($id, 'cancelled', 1, $event->cancelled, 'id='.$id.'cancelled'));
+
 // Description
 $smarty->assign('description_label', lang('description'));
 $smarty->assign('description_input', $this->CreateTextArea(1, $id, $event->description, 'description'));
@@ -155,7 +183,7 @@ $smarty->assign('end_time_input', $this->CreateInputText($id, 'end_time', $end_t
 
 // Capacity - Input text and checkbox if unlimited (in db means 0)
 $smarty->assign('capacity_label', $this->CreateLabelForInput($id, 'capacity_input', $this->Lang('capacity')));
-$smarty->assign('capacity_input', $this->CreateInputText($id, 'capacity_input', $event->capacity, '12', '20'));
+$smarty->assign('capacity_input', $this->CreateInputText($id, 'capacity_input', $event->capacity, '12', '20',($event->capacity == 0) ? 'style="display: none"' : ''));
 $smarty->assign('capacity_unlimited_label', $this->CreateLabelForInput($id, 'capacity_unlimited', $this->Lang('unlimitedcapacity')));
 $smarty->assign('capacity_unlimited', $this->CreateInputCheckbox($id, 'capacity_unlimited', 'unlimited', ($event->capacity == 0) ? 'unlimited' : '', 'id='.$id.'capacity_unlimited'));
 
@@ -172,13 +200,59 @@ $smarty->assign('allowed_feu_groups_input', $this->CreateInputSelectList($id, 'a
 
 // Capacity for each FEU - Input text and checkbox if unlimited (in db means 0)
 $smarty->assign('capacity_per_feu_label', $this->CreateLabelForInput($id, 'capacity_per_feu_input', $this->Lang('capacity_per_feu')));
-$smarty->assign('capacity_per_feu_input', $this->CreateInputText($id, 'capacity_per_feu_input', $event->capacity_per_feu, '12', '20'));
+$smarty->assign('capacity_per_feu_input', $this->CreateInputText($id, 'capacity_per_feu_input', $event->capacity_per_feu, '12', '20',($event->capacity_per_feu == 0) ? 'style="display: none"' : ''));
 $smarty->assign('capacity_per_feu_unlimited_label', $this->CreateLabelForInput($id, 'capacity_per_feu_unlimited', $this->Lang('unlimitedcapacity_per_feu')));
 $smarty->assign('capacity_per_feu_unlimited', $this->CreateInputCheckbox($id, 'capacity_per_feu_unlimited', 'unlimited', ($event->capacity_per_feu == 0) ? 'unlimited' : '', 'id='.$id.'capacity_per_feu_unlimited'));
 
+// Start and End datetimes for the registration -----------------
+$smarty->assign('limited_reg_period_label', $this->CreateLabelForInput($id, 'limited_reg_period', $this->Lang('limited_reg_period_detail')));
+$smarty->assign('limited_reg_period_input', $this->CreateInputCheckbox($id, 'limited_reg_period', '1', ($event->limited_reg_period == 1) ? '1' : '', 'id='.$id.'limited_reg_period'));
+
+// Start date and hour
+$start_datetime = explode(' ', $event->reg_start_datetime);
+$start_date = $start_datetime[0];
+$start_time = explode(':', $start_datetime[1]);
+$start_time = $start_time[0] . ':' . $start_time[1];
+$smarty->assign('reg_start_datetime_label', $this->CreateLabelForInput($id, 'reg_start_date', $this->Lang('reg_start_datetime')));
+$smarty->assign('reg_start_date_input', $this->CreateInputText($id, 'reg_start_date', $start_date));
+$smarty->assign('reg_start_time_input', $this->CreateInputText($id, 'reg_start_time', $start_time, '10'));
+
+// End date and hour
+$end_datetime = explode(' ', $event->reg_end_datetime);
+$end_date = $end_datetime[0];
+$end_time = explode(':', $end_datetime[1]);
+$end_time = $end_time[0] . ':' . $end_time[1];
+$smarty->assign('reg_end_datetime_label', $this->CreateLabelForInput($id, 'reg_end_datetime', $this->Lang('reg_end_datetime')));
+$smarty->assign('reg_end_date_input', $this->CreateInputText($id, 'reg_end_date', $end_date));
+$smarty->assign('reg_end_time_input', $this->CreateInputText($id, 'reg_end_time', $end_time, '10'));
+
+// Custom fields
+$smarty->assign('custom_fields_form', $FieldsManager->get_edit_form($id, 'EventsManager', $event->id, '', '', ''));
+
 /******************************************************************************
 // Display */
 
+$smarty->assign('showtabs', $this->GetPreference('showtabs'));
+if ($this->GetPreference('showtabs'))
+{
+	/* Tabs */
+	// Tabs top
+	$tabs_top = $this->StartTabHeaders();
+	$tabs_top .= $this->SetTabHeader('generalinfo', $this->Lang('generalinfo_tab'));
+	$tabs_top .= $this->SetTabHeader('registrations', $this->Lang('registrations_tab'));
+	$tabs_top .= $this->EndTabHeaders();
+
+	$toassign = array(
+		'tabs_top'=>$tabs_top,
+		'tab_content_start'=>$this->StartTabContent(),
+		'tab_content_end'=>$this->EndTabContent(),
+		'tab_generalinfo_start'=>$this->StartTab('generalinfo'),
+		'tab_registrations_start'=>$this->StartTab('registrations'),
+		'tab_end'=>$this->EndTab()
+		);
+	$smarty->assign($toassign);
+}
+
 // Errors
 foreach ($errors as $error)
 	echo $this->ShowErrors($error);
