@@ -119,7 +119,9 @@ if (count($events) != 0)
 		}
 
 		// Add custom fields
-		$event_smarty->fields = $FieldsManager->get_fieldsbyname('EventsManager', $event->id, '', '', '');
+		$tmp = $FieldsManager->get_fieldsbyname('EventsManager', $event->id, '', '', '');
+		if ($tmp)
+			$event_smarty->fields = $tmp;
 
 		// Add the number of registered users
 		
@@ -139,6 +141,5 @@ $template = $this->GetPreference('dflt_summary_template');
 if  (!empty($params['summarytemplate']))
 	$template = $params['summarytemplate'];
 echo $this->ProcessTemplateFromDatabase('summary_' . $template);
-// Test
 //echo $this->ProcessTemplate('orig_summarytemplate.tpl');
 ?>
\ No newline at end of file
