@@ -2,7 +2,10 @@
 if (!isset($gCms)) exit;
 if (!$this->HasPermission()) exit;
 
-$tabs_available = array('events', 'categories', 'summarytemplates', 'detailtemplates','registrationtemplates', 'registrationslisttemplates', 'preferences');
+$tabs_available = array('events', 'fielddefs', 'categories', 'summarytemplates', 'detailtemplates','registrationtemplates', 'registrationslisttemplates', 'mails', 'preferences');
+
+if (isset($params['active_tab']))
+	$this->SetCurrentTab($params['active_tab']);
 
 echo $this->StartTabHeaders();
 foreach ($tabs_available as $tab_name)
