@@ -65,6 +65,12 @@ if (isset($params['overquotanb']))
 	$smarty->assign('overquotanb', $params['overquotanb']);
 }
 
+if (isset($params['overquotatotal']))
+{
+	// Case where the overquota is because of the total number of reg users, and not the feu limit
+	$smarty->assign('overquotatotal', $params['overquotatotal']);
+}
+
 // Display
 $template = $this->GetPreference('dflt_detail_template');
 if  (!empty($params['detailtemplate']))
