@@ -64,8 +64,28 @@ if (isset($params['event_id']))
 			$nb_persons = 0;
 		}
 
+		// We have to check the case where the limit per FEU is ok, but the total number of registrations asked is higher than the remaining places
+		if ($continue_registration and $nb_persons != 0)
+		{
+			if (!$event->registration_allowed($nb_persons, $registration->nb_persons))
+			{
+
+				$regusers = $event->get_regusers_number();
+				$overquotatotal = $event->capacity - $regusers;
+				
+				$smarty->assign('overquotanb', $nb_persons);
+				$smarty->assign('overquotatotal', $overquotatotal);
+
+				if (isset($params['redirectdetail']) && ($params['redirectdetail']))
+				{
+					// We go back to the orig detail url
+					$this->RedirectForFrontEnd($id, $returnid, 'detail', array('event_id'=>$params['event_id'], 'overquotanb'=>$nb_persons, 'redirectdetail'=>1, 'overquotatotal'=>$overquotatotal), 0);
+				}
+			}
+		}
+
 		// id_user if there to verify the user is connected - if not, go to login page
-		if ($continue_registration && $id_user && ($event->registration_allowed($nb_persons, $registration->nb_persons) OR ($nb_persons == 0)))
+		if ($continue_registration && $id_user && ($event->registration_allowed($nb_persons, $registration->nb_persons)))
 		{
 			$registration->nb_persons = $nb_persons;
 			
@@ -179,7 +199,11 @@ if (isset($params['event_id']))
 
 			// Quantity - If we are in overquota, we display the feu max number
 			$dflt_nb = 1;
-			if (isset($overquota) && $overquota)
+			if (isset($overquotatotal) && $overquotatotal)
+				$dflt_nb = $overquotatotal;
+			elseif ($smarty->get_template_vars('overquotatotal'))
+				$dflt_nb = $smarty->get_template_vars('overquotatotal');
+			elseif (isset($overquota) && $overquota)
 				$dflt_nb = $event->capacity_per_feu;
 			elseif ($smarty->get_template_vars('overquotanb') > 0)
 				$dflt_nb = $event->capacity_per_feu;
