@@ -7,9 +7,13 @@ if (isset($params['event_id']))
 	$registrations = $event->get_registrations();
 	
 	$registrations_smarty = array();
-	foreach ($registrations as $registration)
+
+	if ($registrations)
 	{
-		$registrations_smarty[] = $registration->get_smarty_object();
+		foreach ($registrations as $registration)
+		{
+			$registrations_smarty[] = $registration->get_smarty_object();
+		}
 	}
 	
 	$smarty->assign('registrations', $registrations_smarty);
