@@ -84,16 +84,18 @@ class EventsManager_events_ops
 		if ($show!= 'all' && $show != '')
 		{
 			$query .= ($where_used) ? " AND " : " WHERE ";
+
+			$now = $db->DbTimeStamp(time());
 			
 			switch ($show) {
 				case 'past':
-					$query .= "e.end_datetime < NOW()";
+					$query .= "e.end_datetime < " . $now;
 					break;
 				case 'upcoming':
-					$query .= "e.end_datetime > NOW()";
+					$query .= "e.end_datetime > " . $now;
 					break;
 				case 'currently':
-					$query .="e.start_datetime < NOW() AND e.end_datetime > NOW()";
+					$query .="e.start_datetime < " . $now . " AND e.end_datetime > " . $now;
 					break;
 				case 'custom':
 					if ($start_datetime != '')
