@@ -7,13 +7,17 @@ class EventsManager_user
 		$feu_module = cms_utils::get_module('FrontEndUsers');
 		
 		$this->id = $id;
+
 		$this->username = $feu_module->GetUserName($id);
 		
 		$props = $feu_module->GetUserProperties($id);
-		
-		foreach ($props as $prop)
+
+		if ($props)
 		{
-			$this->$prop['title'] = $prop['data'];
+			foreach ($props as $prop)
+			{
+				$this->$prop['title'] = $prop['data'];
+			}
 		}
 	}
 }
